@@ -20,32 +20,33 @@ class MDSimulation():
     Examples
     --------
 
-    Load packages
-    >>> import parmed
-    >>> from simtk.openmm import unit
-    >>> from ommtk import MDSimulation, select_atoms
+    #Load packages
 
-    instantiate sim from parmed alone, minimize (save h5 file) and run
-    >>> mdsim = MDSimulation(parmed_structure=parmed)
-    >>> mdsim.minimize()
-    >>> minimized_parmed = mdsim.run(2 * unit.nanosecond)
+    import parmed
+    from simtk.openmm import unit
+    from ommtk import MDSimulation, select_atoms
 
-    build sim using a previous trajectory or h5 file
-    >>> mdsim = MDSimulation(parmed_structure=parmed_structure, coordinates=trajectory.h5)
+    #instantiate sim from parmed alone, minimize (save h5 file) and run
+    mdsim = MDSimulation(parmed_structure=parmed)
+    mdsim.minimize()
+    minimized_parmed = mdsim.run(2 * unit.nanosecond)
 
-    build sim with positional restraints, run some equilibration and remove them for longer run
-    >>> protein_atoms = select_atoms(parmed_structure=parmed_structure, keyword_selection='protein')
-    >>> mdsim = MDSimulation(parmed_structure=parmed_structure, atoms_to_restrain=protein_atoms, restraint_weight=4)
-    >>> mdsim.run(1*unit.nanosecond)
-    >>> mdsim.update_restraint_weight(2)
-    >>> mdsim.run(1*unit.nanosecond)
-    >>> mdsim.remove_positional_restraints()
-    >>> end_parmed = mdsim.run(4 * unit.nanosecond)
+    #build sim using a previous trajectory or h5 file
+    mdsim = MDSimulation(parmed_structure=parmed_structure, coordinates=trajectory.h5)
+
+    #build sim with positional restraints, run some equilibration and remove them for longer run
+    protein_atoms = select_atoms(parmed_structure=parmed_structure, keyword_selection='protein')
+    mdsim = MDSimulation(parmed_structure=parmed_structure, atoms_to_restrain=protein_atoms, restraint_weight=4)
+    mdsim.run(1*unit.nanosecond)
+    mdsim.update_restraint_weight(2)
+    mdsim.run(1*unit.nanosecond)
+    mdsim.remove_positional_restraints()
+    >> end_parmed = mdsim.run(4 * unit.nanosecond)
 
     Parameters
     ----------
     parmed_structure : Parmed.Structure
-        The Parmed Topology Object containing topology nand force field parameters
+        The Parmed Topology Object containing topology and force field parameters
 
     coordinates: unit.Quantity or mdtraj.Trajectory, optional
         Alternate coordiantes to be used if parmed_structure coordinates aren't going to be used
@@ -57,7 +58,7 @@ class MDSimulation():
         Box vectors to be used for simulation. If not specified box vectors are taken from parmed_structure
 
     cwd : string, optional
-        directory for storing simulation files. If None a folder will be created in /tmp/ with a unique 6 digit randomized name
+        directory for storing simulation files. If None a folder will be created in /tmp/ with a unique 6 name
 
     temperature: unit.Quantity, optional
         temperature for running simulation and Langevin bath if used. Default 300 Kelvin
@@ -66,19 +67,19 @@ class MDSimulation():
         pressure at which to hold the simulation via barostat. If None no temperature control will be used
 
     membrane : bool, optional
-        flag for whether or not the simulation contains a membrane, which will ensure the correct barostat is used for membranes
+        flag for whether or not the simulation contains a membrane, which will ensure the correct barostat is used
 
-    integrator_type : {'Langevin, Verlet'}, optional
-        string indicating integrator type to use. Default: Langevin
+    integrator_type : string Langevin or Verlet, optional
+        string indicating integrator type to use. Default Langevin
 
-    platform_name : {'Reference, CPU, CUDA, OpenCL'}, optional
-        string indicating which platform to use for running simulation. If None the fastest platform available will be used
+    platform_name : String Reference, CPU, CUDA, OpenCL, optional
+        string indicating which platform to use. If None the fastest platform available will be used
 
-    nonbonded_method : string, optional
+    nonbonded_method : string PME, None, optional
         string indicating nonbonded method to use, default is PME
 
     nonbonded_cutoff : unit.Quantity, optional
-        nonbonded cutoff distance, default 1 *unit.nanometer
+        nonbonded cutoff distance, default 1 unit.nanometer
 
     atoms_to_freeze : list of integers, optional
         list of atom indeces indicating which atoms to freeze during the simulation
@@ -89,10 +90,10 @@ class MDSimulation():
     restraint_weight : unit.Quantity or float, optional
         force constant to be used for positional restraints. If not units given, they will be assumed as kcal/mol/A.
 
-    constraints :  {'HBonds', 'HAngles' ,'AllBonds'}, optional
+    constraints :  'HBonds', 'HAngles' ,'AllBonds', optional
         type of constraints to use during simulation. Default is HBonds
 
-    implicit_solvent_model : {'HCT', 'OBC1', 'OBC2', 'GBn', 'GBn2'}, optional
+    implicit_solvent_model : 'HCT', 'OBC1', 'OBC2', 'GBn', 'GBn2', optional
         string indicating the type of implicit model to use if any
 
     hmr : boolean, optional
@@ -119,7 +120,6 @@ class MDSimulation():
 
     traj_out : string, optional
         name of file for writing trajectory information. Defaults to 'trajectory.h5'
-
     """
     def __init__(self, parmed_structure, coordinates=None,
                  velocities=None, box_vectors=None,
@@ -1375,7 +1375,7 @@ class SimulatedTemperingSimulation(MDSimulation):
                                                   minTemperature=self.minTemperature,
                                                   maxTemperature=self.maxTemperature,
                                                   reportInterval=self.reportInterval,
-                                                  reportFile=os.join(self.cwd,self.reportFile))
+                                                  reportFile=os.path.join(self.cwd,self.reportFile))
 
     def run(self, time):
         """
