@@ -41,7 +41,7 @@ class SegmentMappingSim(MetadynamicSimulation):
 
     """
     def __init__(self, num_segs = 10, seg_sim_time=.5 * unit.nanosecond, scan_bias=45,
-                 scan_time = 1 * unit.nanosecond,
+                 scan_time = 1 * unit.nanosecond, max_scan_time=10 * unit.nanosecond,unbound_distance=4,
                  prod_bias=5, num_cycles=1,
                  **kwargs):
 
@@ -52,8 +52,10 @@ class SegmentMappingSim(MetadynamicSimulation):
         self.seg_sim_time = seg_sim_time
         self.scan_bias = scan_bias
         self.scan_time = scan_time
+        self.max_scan_time = max_scan_time
         self.prod_bias = prod_bias
         self.num_cycles = num_cycles
+        self.unbound_distance=unbound_distance
 
         if self.CV_list[0][0]!='Distance':
             raise ValueError('Segment Map Sim where the first CV is not distance not yet supported')
@@ -61,22 +63,13 @@ class SegmentMappingSim(MetadynamicSimulation):
         if self.scan_bias < self.prod_bias:
             print('WARNING: scan bias should be high (40-50) and prod bias should be low (5-10)')
 
-        #find unbinding distance algorithmically
-        lig_atom_index = select_atoms(self.parmed_structure, keyword_selection='ligand')
-        prot_atom_index = select_atoms(self.parmed_structure, keyword_selection='protein')
-        lig_positions = np.array(self.positions.value_in_unit(unit.nanometer))[lig_atom_index]
-        prot_positions = np.array(self.positions.value_in_unit(unit.nanometer))[prot_atom_index]
 
-        #flat bottom function is designed to find max protein radius around ligand that could be important
-        #for sampling. Hard code the scale factor though, since if it's too big the scan will run for forever
-        self.unbound_distance = find_flat_bottom_radius(lig_positions, prot_positions, 1.15)
-        print('using the following value for unbound distance {}'.format(self.unbound_distance))
 
     def run(self):
         """
         Run the segment mapping protocol defined by input variables.
 
-        :return:
+        :return: updated parmed.Structure object
         """
 
         #run initial run with initial biasfactor
@@ -105,9 +98,11 @@ class SegmentMappingSim(MetadynamicSimulation):
 
         print('CV distances {}'.format(distances))
 
-        while all(distances < self.unbound_distance):
+        scan_clock = self.scan_time
+        while all(distances < np.min(distances)+self.unbound_distance) and  scan_clock<self.max_scan_time:
             print('failed to unbind, scanning for another .5 ns')
             print('CV distances {}'.format(distances))
+            scan_clock += .5 * unit.nanosecond
             nsteps = int(.5 * unit.nanosecond / self.step_length)
 
             self.metaD.step(self.simulation, nsteps)
@@ -117,7 +112,10 @@ class SegmentMappingSim(MetadynamicSimulation):
 
             distances = np.array(CVs)[:, 0]
         else:
-            print('ligand reached unbinding distance, proceeding with forced sampling')
+            if scan_clock<self.max_scan_time:
+                print('ligand reached unbinding distance, proceeding with forced sampling')
+            else:
+                print('failed to unbind in max_scan_time, proceeding anyway')
 
         print('distances from scan: {}'.format(distances))
 
